@@ -50,95 +50,94 @@
 
 #include "dialog.h"
 
+#include <QComboBox>
+#include <QGridLayout>
 #include <QLabel>
 #include <QLineEdit>
-#include <QComboBox>
-#include <QSpinBox>
 #include <QPushButton>
-#include <QGridLayout>
+#include <QSerialPortInfo>
+#include <QSpinBox>
 
-#include <QtSerialPort/QSerialPortInfo>
-
-QT_USE_NAMESPACE
-
-Dialog::Dialog(QWidget *parent)
-    : QDialog(parent)
-    , transactionCount(0)
-    , serialPortLabel(new QLabel(tr("Serial port:")))
-    , serialPortComboBox(new QComboBox())
-    , waitRequestLabel(new QLabel(tr("Wait request, msec:")))
-    , waitRequestSpinBox(new QSpinBox())
-    , responseLabel(new QLabel(tr("Response:")))
-    , responseLineEdit(new QLineEdit(tr("Hello, I'm Slave.")))
-    , trafficLabel(new QLabel(tr("No traffic.")))
-    , statusLabel(new QLabel(tr("Status: Not running.")))
-    , runButton(new QPushButton(tr("Start")))
+Dialog::Dialog(QWidget *parent) :
+    QDialog(parent),
+    m_serialPortLabel(new QLabel(tr("Serial port:"))),
+    m_serialPortComboBox(new QComboBox),
+    m_waitRequestLabel(new QLabel(tr("Wait request, msec:"))),
+    m_waitRequestSpinBox(new QSpinBox),
+    m_responseLabel(new QLabel(tr("Response:"))),
+    m_responseLineEdit(new QLineEdit(tr("Hello, I'm Slave."))),
+    m_trafficLabel(new QLabel(tr("No traffic."))),
+    m_statusLabel(new QLabel(tr("Status: Not running."))),
+    m_runButton(new QPushButton(tr("Start")))
 {
-    waitRequestSpinBox->setRange(0, 10000);
-    waitRequestSpinBox->setValue(10000);
+    m_waitRequestSpinBox->setRange(0, 10000);
+    m_waitRequestSpinBox->setValue(10000);
 
     const auto infos = QSerialPortInfo::availablePorts();
     for (const QSerialPortInfo &info : infos)
-        serialPortComboBox->addItem(info.portName());
+        m_serialPortComboBox->addItem(info.portName());
 
     auto mainLayout = new QGridLayout;
-    mainLayout->addWidget(serialPortLabel, 0, 0);
-    mainLayout->addWidget(serialPortComboBox, 0, 1);
-    mainLayout->addWidget(waitRequestLabel, 1, 0);
-    mainLayout->addWidget(waitRequestSpinBox, 1, 1);
-    mainLayout->addWidget(runButton, 0, 2, 2, 1);
-    mainLayout->addWidget(responseLabel, 2, 0);
-    mainLayout->addWidget(responseLineEdit, 2, 1, 1, 3);
-    mainLayout->addWidget(trafficLabel, 3, 0, 1, 4);
-    mainLayout->addWidget(statusLabel, 4, 0, 1, 5);
+    mainLayout->addWidget(m_serialPortLabel, 0, 0);
+    mainLayout->addWidget(m_serialPortComboBox, 0, 1);
+    mainLayout->addWidget(m_waitRequestLabel, 1, 0);
+    mainLayout->addWidget(m_waitRequestSpinBox, 1, 1);
+    mainLayout->addWidget(m_runButton, 0, 2, 2, 1);
+    mainLayout->addWidget(m_responseLabel, 2, 0);
+    mainLayout->addWidget(m_responseLineEdit, 2, 1, 1, 3);
+    mainLayout->addWidget(m_trafficLabel, 3, 0, 1, 4);
+    mainLayout->addWidget(m_statusLabel, 4, 0, 1, 5);
     setLayout(mainLayout);
 
     setWindowTitle(tr("Blocking Slave"));
-    serialPortComboBox->setFocus();
+    m_serialPortComboBox->setFocus();
 
-    connect(runButton, &QPushButton::clicked, this, &Dialog::startSlave);
-    connect(&thread, &SlaveThread::request, this,&Dialog::showRequest);
-    connect(&thread, &SlaveThread::error, this, &Dialog::processError);
-    connect(&thread, &SlaveThread::timeout, this, &Dialog::processTimeout);
+    connect(m_runButton, &QPushButton::clicked, this, &Dialog::startSlave);
+    connect(&m_thread, &SlaveThread::request, this,&Dialog::showRequest);
+    connect(&m_thread, &SlaveThread::error, this, &Dialog::processError);
+    connect(&m_thread, &SlaveThread::timeout, this, &Dialog::processTimeout);
 
-    connect(serialPortComboBox, static_cast<void (QComboBox::*)(const QString &)>(&QComboBox::currentIndexChanged),
+    connect(m_serialPortComboBox, QOverload<const QString &>::of(&QComboBox::currentIndexChanged),
             this, &Dialog::activateRunButton);
-    connect(waitRequestSpinBox, static_cast<void (QSpinBox::*)(const QString &)>(&QSpinBox::valueChanged),
+    connect(m_waitRequestSpinBox, QOverload<const QString &>::of(&QSpinBox::valueChanged),
             this, &Dialog::activateRunButton);
-    connect(responseLineEdit, &QLineEdit::textChanged, this, &Dialog::activateRunButton);
+    connect(m_responseLineEdit, &QLineEdit::textChanged, this, &Dialog::activateRunButton);
 }
 
 void Dialog::startSlave()
 {
-    runButton->setEnabled(false);
-    statusLabel->setText(tr("Status: Running, connected to port %1.")
-                         .arg(serialPortComboBox->currentText()));
-    thread.startSlave(serialPortComboBox->currentText(),
-                      waitRequestSpinBox->value(),
-                      responseLineEdit->text());
+    m_runButton->setEnabled(false);
+    m_statusLabel->setText(tr("Status: Running, connected to port %1.")
+                           .arg(m_serialPortComboBox->currentText()));
+    m_thread.startSlave(m_serialPortComboBox->currentText(),
+                        m_waitRequestSpinBox->value(),
+                        m_responseLineEdit->text());
 }
 
 void Dialog::showRequest(const QString &s)
 {
-    trafficLabel->setText(tr("Traffic, transaction #%1:"
-                             "\n\r-request: %2"
-                             "\n\r-response: %3")
-                          .arg(++transactionCount).arg(s).arg(responseLineEdit->text()));
+    m_trafficLabel->setText(tr("Traffic, transaction #%1:"
+                               "\n\r-request: %2"
+                               "\n\r-response: %3")
+                            .arg(++m_transactionCount)
+                            .arg(s)
+                            .arg(m_responseLineEdit->text()));
 }
 
 void Dialog::processError(const QString &s)
 {
     activateRunButton();
-    statusLabel->setText(tr("Status: Not running, %1.").arg(s));
-    trafficLabel->setText(tr("No traffic."));
+    m_statusLabel->setText(tr("Status: Not running, %1.").arg(s));
+    m_trafficLabel->setText(tr("No traffic."));
 }
 
 void Dialog::processTimeout(const QString &s)
 {
-    statusLabel->setText(tr("Status: Running, %1.").arg(s));
-    trafficLabel->setText(tr("No traffic."));
+    m_statusLabel->setText(tr("Status: Running, %1.").arg(s));
+    m_trafficLabel->setText(tr("No traffic."));
 }
+
 void Dialog::activateRunButton()
 {
-    runButton->setEnabled(true);
+    m_runButton->setEnabled(true);
 }
